==> spip_3.2.11.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'إعادة تأصيل',
	'boxstr_close' => 'إغلاق',
	'boxstr_current' => '@current@ / @total@',
	'boxstr_next' => 'التالي',
	'boxstr_previous' => 'السابق',
	'boxstr_slideshowStart' => 'عرض متواصل',
	'boxstr_slideshowStop' => 'إيقاف',
	'boxstr_zoom' => 'تكبير (زوم)',

	// E
	'explication_selecteur' => 'حدد هدف العناصر التي ستطلق الصندوق (عبارة CSS، او مجال jQuery)',
	'explication_selecteur_galerie' => 'حدد هدف العناصر المطلوب تجميعها في صالة عرض (عبارة CSS، او مجال jQuery)',
	'explication_splash_url' => 'أدخل هنا عنوان الوسيط الذي ترغب عرضه آلياً في مربع لدى أول زيارة للموقع العمومي.',
	'explication_traiter_toutes_images' => 'إدخال صندوق على كل الصور؟',

	// L
	'label_active' => 'تفعيل صندوق الفرجة في الموقع العمومي',
	'label_apparence' => 'المظهر',
	'label_aucun_style' => 'دون كساء إفتراضي',
	'label_choix_transition_elastic' => 'مطاط',
	'label_choix_transition_fade' => 'دمج متسلسل',
	'label_choix_transition_none' => 'بدون تأثيرات انتقال',
	'label_maxheight' => 'الحد الأقصى للارتفاع (% أو نقاط)',
	'label_maxwidth' => 'الحد الأقصى للعرض (% أو نقاط)',
	'label_minheight' => 'الحد الأدنى للارتفاع (% أو نقاط)',
	'label_minwidth' => 'الحد الأدنى للعرض (% أو نقاط)',
	'label_opacite' => 'شفافية الخلفية',
	'label_selecteur_commun' => 'عموماً',
	'label_selecteur_galerie' => 'في صالة العرض',
	'label_skin' => 'الكساء البصري',
	'label_slideshow_speed' => 'فترة عرض الصور خلال العرض المتواصل (ألف من الثانية)',
	'label_speed' => 'سرعة الانتقال (ألف من الثانية)',
	'label_splash' => 'شاشة البداية',
	'label_splash_height' => 'الارتفاع (٪ او px)',
	'label_splash_url' => 'عنوان شاشة البداية',
	'label_splash_width' => 'العرض (٪ او px)',
	'label_traiter_toutes_images' => 'الصور',
	'label_transition' => 'الانتقال بين عرضين',

	// T
	'titre_menu_box' => 'صندوق الفرجة',
	'titre_page_configurer_box' => 'إعداد صندوق الفرجة'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'إعادة تأصيل',
	'boxstr_close' => 'إغلاق',
	'boxstr_current' => '@current@ / @total@',
	'boxstr_dialog_title_default' => 'مربع حوار',
	'boxstr_dialog_title_medias' => 'عرض وسيط',
	'boxstr_loading' => 'تحميل…',
	'boxstr_next' => 'التالي',
	'boxstr_press_escape_to_close' => 'الضغط على مفتاح الخو،ج (esc) للإغلاق',
	'boxstr_previous' => 'السابق',
	'boxstr_slideshowStart' => 'عرض متواصل',
	'boxstr_slideshowStop' => 'إيقاف',
	'boxstr_zoom' => 'تكبير (زوم)',

	// E
	'explication_selecteur' => 'حدد هدف العناصر التي ستطلق الصندوق (عبارة CSS، او مجال jQuery)',
	'explication_selecteur_galerie' => 'حدد هدف العناصر المطلوب تجميعها في صالة عرض (عبارة CSS، او مجال jQuery)',
	'explication_splash_url' => 'أدخل هنا عنوان الوسيط الذي ترغب عرضه آلياً في مربع لدى أول زيارة للموقع العمومي.',
	'explication_traiter_toutes_images' => 'إدخال صندوق على كل الصور؟',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'الاسود الافتراضي',
	'info_box_lity_nom_skin__simple_white' => 'الفاتح الافتراضي',
	'info_box_lity_nom_skin_fancybox' => 'طريقة Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'طريقة Thickbox',

	// L
	'label_active' => 'تفعيل صندوق الفرجة في الموقع العمومي',
	'label_apparence' => 'المظهر',
	'label_aucun_style' => 'دون كساء إفتراضي',
	'label_choix_transition_elastic' => 'مطاط',
	'label_choix_transition_fade' => 'دمج متسلسل',
	'label_choix_transition_none' => 'بدون تأثيرات انتقال',
	'label_maxheight' => 'الحد الأقصى للارتفاع (% أو نقاط)',
	'label_maxwidth' => 'الحد الأقصى للعرض (% أو نقاط)',
	'label_minheight' => 'الحد الأدنى للارتفاع (% أو نقاط)',
	'label_minwidth' => 'الحد الأدنى للعرض (% أو نقاط)',
	'label_opacite' => 'شفافية الخلفية',
	'label_selecteur_commun' => 'عموماً',
	'label_selecteur_galerie' => 'في صالة العرض',
	'label_skin' => 'الكساء البصري',
	'label_slideshow_speed' => 'فترة عرض الصور خلال العرض المتواصل (ألف من الثانية)',
	'label_speed' => 'سرعة الانتقال (ألف من الثانية)',
	'label_splash' => 'شاشة البداية',
	'label_splash_height' => 'الارتفاع (٪ او px)',
	'label_splash_url' => 'عنوان شاشة البداية',
	'label_splash_width' => 'العرض (٪ او px)',
	'label_traiter_toutes_images' => 'الصور',
	'label_transition' => 'الانتقال بين عرضين',

	// T
	'titre_menu_box' => 'صندوق الفرجة',
	'titre_page_configurer_box' => 'إعداد صندوق الفرجة'
);
